==> bpkio_cli-1.3.0-py3-none-any.whl: bpkio_cli/commands/url.py <==
import click
import cloup
from bpkio_api.helpers.handlers import ContentHandler, factory
from bpkio_api.helpers.source_type import SourceTypeDetector
from bpkio_api.models import SourceType
from pydantic import HttpUrl, parse_obj_as

import bpkio_cli.click_options as bic_options
from bpkio_cli.click_mods import ApiResourceGroup
from bpkio_cli.commands.sources import create as source_create
from bpkio_cli.core.app_context import AppContext
from bpkio_cli.core.config_provider import ConfigProvider
from bpkio_cli.utils.profile_maker import make_transcoding_profile
from bpkio_cli.writers.content_display import display_content
from bpkio_cli.writers.players import StreamPlayer
from bpkio_cli.writers.tables import display_table


def determine_source_type(full_url) -> SourceType | None:
    source_type = SourceTypeDetector.determine_source_type(full_url)
    if not source_type:
        click.secho(
            "Could not determine the type of source for that URL", fg="red", bold="true"
        )
        return None
    else:
        return source_type


def get_handler(sub: int | None = None) -> ContentHandler:
    ctx = click.get_current_context()
    url = ctx.obj.resources.last()

    handler: ContentHandler = factory.create_handler(url)

    if not sub:
        return handler
    else:
        if not handler.has_children():
            raise click.UsageError(
                "`--sub` cannot be used with this source, as it has no children URLs"
            )
        return handler.get_child(sub)


# Group: URLs
@cloup.group(
    cls=ApiResourceGroup, help="Work directly with URLs", resource_class=HttpUrl
)
@cloup.argument(
    "full_url",
    help=("The URL to work with"),
)
@click.pass_obj
def url(obj: AppContext, full_url: HttpUrl):
    full_url = parse_obj_as(HttpUrl, full_url)
    obj.cache.record(full_url)


# Command: GET
@cloup.command(help="Get details about a URL")
@click.pass_obj
def get(obj: AppContext):
    full_url = obj.resources.last()
    source_type = determine_source_type(full_url)

    click.secho("This appears to be a source of type: %s" % source_type.value)


# Command: CHECK
@cloup.command(help="Checks the validity of a URL")
@bic_options.json
@bic_options.list()
@click.pass_obj
def check(obj: AppContext, select_fields, sort_fields, json):
    full_url = obj.resources.last()
    source_type = determine_source_type(full_url)

    if source_type:
        results = obj.api.sources.check(type=source_type, url=full_url)

        obj.response_handler.treat_list_resources(
            results, json=json, select_fields=select_fields, sort_fields=sort_fields
        )


# --- READ Command
@cloup.command(
    help="Loads and displays the content of a URL"
    ", optionally highlighted with relevant information"
)
@bic_options.read
@bic_options.url
@bic_options.table
def read(
    sub: int, table: bool, raw: bool, top: bool, tail: bool, pager: bool, **kwargs
):
    handler = get_handler(sub)

    display_content(
        handler=handler,
        max=1,
        interval=0,
        table=table,
        raw=raw,
        top=top,
        tail=tail,
        pager=pager,
    )


# --- POLL Command
@cloup.command(help="Similar to `read`, but regularly re-load the URL's content")
@bic_options.read
@bic_options.url
@bic_options.poll
@bic_options.table
def poll(
    sub: int,
    max: int,
    interval: int,
    raw: bool,
    diff: bool,
    top: bool,
    tail: bool,
    clear: bool,
    table: bool,
    **kwargs,
):
    handler = get_handler(sub)

    display_content(
        handler=handler,
        max=max,
        interval=interval,
        table=table,
        raw=raw,
        diff=diff,
        top=top,
        tail=tail,
        clear=clear,
    )


# --- PLAY Command
@cloup.command(help="Open the URL in a web player", aliases=["open"])
@click.option(
    "-s",
    "--sub",
    type=int,
    default=None,
    help="For HLS, reads a sub-playlist (by index - "
    "as given by the `read ID --table` option with the main playlist)",
)
@click.option(
    "-p",
    "--player",
    default="CONFIG",
    help="The template for a player URL",
    type=str,
    is_flag=False,
    flag_value="CHOICE",
)
def play(sub: int, player: str):
    handler = get_handler(sub)

    if player == "CONFIG":
        player = ConfigProvider().get("player")

    if player == "CHOICE":
        player = StreamPlayer.prompt_player()

    StreamPlayer().launch(url=handler.url, template=player, name="")


# --- CREATE Command
@cloup.command(help="Create a Source from the URL")
@cloup.option("--name", help="Name for the source", required=False)
@click.pass_context
def store(ctx, name):
    full_url = ctx.obj.resources.last()

    ctx.invoke(source_create, url=full_url, name=name)


# --- PROFILE Command
@cloup.command(help="Create a Transcoding Profile from the content of the URL")
@click.option(
    "--table/--no-table",
    "with_table",
    is_flag=True,
    default=False,
    help="Add or hide summary information about the content of the resource",
)
@click.pass_obj
def profile(obj: AppContext, with_table: bool):
    handler = get_handler()

    profile = make_transcoding_profile(handler)

    if with_table:
        display_table(profile["transcoding"]["jobs"])
    else:
        obj.response_handler.treat_single_resource(profile, json=True)


url.add_section(
    cloup.Section("Content Commands", [check, get, read, poll, play, profile])
)

url.add_section(cloup.Section("Other Commands", [store]))

==> bpkio_cli-1.5.0-py3-none-any.whl: bpkio_cli/commands/url.py <==
import click
import cloup
from bpkio_api.helpers.handlers import ContentHandler, factory
from bpkio_api.helpers.source_type import SourceTypeDetector
from bpkio_api.models import SourceType
from pydantic import HttpUrl, parse_obj_as

import bpkio_cli.click_options as bic_options
from bpkio_cli.click_mods import ApiResourceGroup
from bpkio_cli.commands.sources import create as source_create
from bpkio_cli.core.app_context import AppContext
from bpkio_cli.core.config_provider import ConfigProvider
from bpkio_cli.utils.profile_maker import make_transcoding_profile
from bpkio_cli.writers.content_display import display_content
from bpkio_cli.writers.players import StreamPlayer
from bpkio_cli.writers.tables import display_table
from bpkio_cli.utils.url_builders import ask_for_user_agent


def determine_source_type(full_url) -> SourceType | None:
    source_type = SourceTypeDetector.determine_source_type(full_url)
    if not source_type:
        click.secho(
            "Could not determine the type of source for that URL", fg="red", bold="true"
        )
        return None
    else:
        return source_type


def get_handler(
    sub: int | None = None, user_agent: str | None = None
) -> ContentHandler:
    ctx = click.get_current_context()
    url = ctx.obj.resources.last()

    if user_agent == "SELECT":
        ask_for_user_agent(url)

    handler: ContentHandler = factory.create_handler(
        url, user_agent=ConfigProvider().get_user_agent(user_agent)
    )

    if not sub:
        return handler
    else:
        if not handler.has_children():
            raise click.UsageError(
                "`--sub` cannot be used with this source, as it has no children URLs"
            )
        return handler.get_child(sub)


# Group: URLs
@cloup.group(
    cls=ApiResourceGroup, help="Work directly with URLs", resource_class=HttpUrl
)
@cloup.argument(
    "full_url",
    help=("The URL to work with"),
)
@click.pass_obj
def url(obj: AppContext, full_url: HttpUrl):
    full_url = parse_obj_as(HttpUrl, full_url)
    obj.cache.record(full_url)


# Command: GET
@cloup.command(help="Get details about a URL")
@click.pass_obj
def get(obj: AppContext):
    full_url = obj.resources.last()
    source_type = determine_source_type(full_url)

    click.secho("This appears to be a source of type: %s" % source_type.value)


# Command: CHECK
@cloup.command(help="Checks the validity of a URL")
@bic_options.json
@bic_options.list()
@click.pass_obj
def check(obj: AppContext, select_fields, sort_fields, json):
    full_url = obj.resources.last()
    source_type = determine_source_type(full_url)

    if source_type:
        results = obj.api.sources.check(type=source_type, url=full_url)

        obj.response_handler.treat_list_resources(
            results, json=json, select_fields=select_fields, sort_fields=sort_fields
        )


# --- READ Command
@cloup.command(
    help="Loads and displays the content of a URL"
    ", optionally highlighted with relevant information"
)
@bic_options.read
@bic_options.url
@bic_options.table
def read(
    sub: int,
    table: bool,
    raw: bool,
    top: bool,
    tail: bool,
    pager: bool,
    user_agent: str,
    **kwargs,
):
    handler = get_handler(sub, user_agent)

    display_content(
        handler=handler,
        max=1,
        interval=0,
        table=table,
        raw=raw,
        top=top,
        tail=tail,
        pager=pager,
    )


# --- POLL Command
@cloup.command(help="Similar to `read`, but regularly re-load the URL's content")
@bic_options.read
@bic_options.url
@bic_options.poll
@bic_options.table
def poll(
    sub: int,
    user_agent: str,
    max: int,
    interval: int,
    raw: bool,
    diff: bool,
    top: bool,
    tail: bool,
    clear: bool,
    table: bool,
    **kwargs,
):
    handler = get_handler(sub, user_agent)

    display_content(
        handler=handler,
        max=max,
        interval=interval,
        table=table,
        raw=raw,
        diff=diff,
        top=top,
        tail=tail,
        clear=clear,
    )


# --- PLAY Command
@cloup.command(help="Open the URL in a web player", aliases=["open"])
@click.option(
    "-s",
    "--sub",
    type=int,
    default=None,
    help="For HLS, reads a sub-playlist (by index - "
    "as given by the `read ID --table` option with the main playlist)",
)
@click.option(
    "-p",
    "--player",
    default="CONFIG",
    help="The template for a player URL",
    type=str,
    is_flag=False,
    flag_value="CHOICE",
)
def play(sub: int, player: str):
    handler = get_handler(sub)

    if player == "CONFIG":
        player = ConfigProvider().get("player")

    if player == "CHOICE":
        player = StreamPlayer.prompt_player()

    StreamPlayer().launch(url=handler.url, template=player, name="")


# --- CREATE Command
@cloup.command(help="Create a Source from the URL")
@cloup.option("--name", help="Name for the source", required=False)
@click.pass_context
def store(ctx, name):
    full_url = ctx.obj.resources.last()

    ctx.invoke(source_create, url=full_url, name=name)


# --- PROFILE Command
@cloup.command(help="Create a Transcoding Profile from the content of the URL")
@click.option(
    "--table/--no-table",
    "with_table",
    is_flag=True,
    default=False,
    help="Add or hide summary information about the content of the resource",
)
@click.pass_obj
def profile(obj: AppContext, with_table: bool):
    handler = get_handler()

    profile = make_transcoding_profile(handler)

    if with_table:
        display_table(profile["transcoding"]["jobs"])
    else:
        obj.response_handler.treat_single_resource(profile, json=True)


url.add_section(
    cloup.Section("Content Commands", [check, get, read, poll, play, profile])
)

url.add_section(cloup.Section("Other Commands", [store]))
